/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { useCallback, useRef } from 'react';
import { useHistory } from '@docusaurus/router';
import { useLocationChange } from '../utils/useLocationChange';
import { ThemeClassNames } from '../utils/ThemeClassNames';
function programmaticFocus(el) {
    el.setAttribute('tabindex', '-1');
    el.focus();
    el.removeAttribute('tabindex');
}
/** This hook wires the logic for a skip-to-content link. */
export function useSkipToContent() {
    const containerRef = useRef(null);
    const { action } = useHistory();
    const handleSkip = useCallback((e) => {
        e.preventDefault();
        const targetElement = document.querySelector('main:first-of-type') ??
            document.querySelector(`.${ThemeClassNames.wrapper.main}`);
        if (targetElement) {
            programmaticFocus(targetElement);
        }
    }, []);
    useLocationChange(({ location }) => {
        if (containerRef.current && !location.hash && action === 'PUSH') {
            programmaticFocus(containerRef.current);
        }
    });
    return { containerRef, handleSkip };
}
//# sourceMappingURL=useSkipToContent.js.map